summaryrefslogtreecommitdiffstats
path: root/test/titerate.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/titerate.c')
-rw-r--r--test/titerate.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/titerate.c b/test/titerate.c
index 8df1563..63eb84f 100644
--- a/test/titerate.c
+++ b/test/titerate.c
@@ -934,9 +934,9 @@ test_iterate(void)
fapl2 = H5Pcopy(fapl);
CHECK(fapl2, FAIL, "H5Pcopy");
- /* Set the "use the latest version of the format" flag for creating objects in the file */
- ret = H5Pset_latest_format(fapl2, TRUE);
- CHECK(ret, FAIL, "H5Pset_latest_format");
+ /* Set the "use the latest version of the format" bounds for creating objects in the file */
+ ret = H5Pset_format_bounds(fapl2, H5F_FORMAT_LATEST, H5F_FORMAT_LATEST);
+ CHECK(ret, FAIL, "H5Pset_format_bounds");
/* These next tests use the same file */
for(new_format = FALSE; new_format <= TRUE; new_format++) {